@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::FromProto;
-$XML::Grammar::Screenplay::FromProto::VERSION = '0.22.0';
+$XML::Grammar::Screenplay::FromProto::VERSION = '0.22.1';
 use strict;
 use warnings;
 use autodie;
@@ -60,7 +60,8 @@ sub _handle_elem_of_name_code_blk
     my $good = sub {
         my ( $k, $v ) = @_;
         my $input_v = $elem->lookup_attr($k);
-        die "wrong value \"$v\""
+        die
+"wrong value \"$input_v\" for attribute \"$k\" for element \"<code_blk>\""
             if ( ref($v) eq "" ? ( $v ne $input_v ) : ( $input_v !~ /$v/ ) );
         return ( $k, $input_v );
     };
@@ -73,10 +74,12 @@ sub _handle_elem_of_name_code_blk
                     {
                         start => [
                             "code_blk",
-                            $good->( "syntax",   "text" ),
-                            $good->( "tag_role", "asciiart" ),
-                            $good->( "title",    qr#.#ms ),
-                            $good->( "alt",      qr#.#ms ),
+                            $good->( "syntax", "text" ),
+                            $good->(
+                                "tag_role", qr#\A(?:asciiart|code_block)\z#,
+                            ),
+                            $good->( "title", qr#.#ms ),
+                            $good->( "alt",   qr#.#ms ),
                         ],
                         in => sub {
                             my $inner_text =
@@ -254,7 +257,7 @@ Converts the file $path_to_file to XML and returns it.
 
 =head1 VERSION
 
-version 0.22.0
+version 0.22.1
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
